@@ -1,10 +1,8 @@
-/* ============================================================
- *
+/*
  * SPDX-FileCopyrightText: 2008-2011 Kare Sars <kare.sars@iki.fi>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
- *
- * ============================================================ */
+ */
 
 #include "ksanebutton.h"
 
@@ -17,12 +15,12 @@ KSaneButton::KSaneButton(QWidget *parent, const QString &ltext)
     initButton(ltext);
 }
 
-KSaneButton::KSaneButton(QWidget *parent, KSaneOption *option)
+KSaneButton::KSaneButton(QWidget *parent, KSaneCore::Option *option)
     : KSaneOptionWidget(parent, option)
 {
     initButton(option->title());
     setToolTip(option->description());
-    connect(this, &KSaneButton::clicked, option, &KSaneOption::setValue);
+    connect(this, &KSaneButton::clicked, option, &KSaneCore::Option::setValue);
 }
 
 KSaneButton::~KSaneButton()
