@@ -1,10 +1,8 @@
-/* ============================================================
- *
+/*
  * SPDX-FileCopyrightText: 2011 Kare Sars <kare.sars@iki.fi>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
- *
- * ============================================================ */
+ */
 
 #ifndef KSANE_OPTION_WIDGET_H
 #define KSANE_OPTION_WIDGET_H
@@ -14,7 +12,7 @@
 #include <QLabel>
 #include <QGridLayout>
 
-#include "ksaneoption.h"
+#include <Option>
 
 namespace KSaneIface
 {
@@ -38,25 +36,23 @@ public:
      */
     KSaneOptionWidget(QWidget *parent, const QString &labelText);
 
-    KSaneOptionWidget(QWidget *parent, KSaneOption *option);
+    KSaneOptionWidget(QWidget *parent, KSaneCore::Option *option);
     ~KSaneOptionWidget() override;
 
     void setLabelText(const QString &text);
 
     int labelWidthHint();
     void setLabelWidth(int labelWidth);
-    
+
 protected Q_SLOTS:
-    void updateVisibility(); 
-    
+    void updateVisibility();
+
 protected:
     void initWidget();
-   
+
     QLabel      *m_label;
     QGridLayout *m_layout;
-    KSaneOption *m_option = nullptr;
-    
-    
+    KSaneCore::Option *m_option = nullptr;
 };
 
 }  // NameSpace KSaneIface
